forked from IQ.Lvbs/IQ.Pilot
IQ.Pilot Prebuilt Release @ ab07000
This commit is contained in:
13
tinygrad_repo/test/external/external_cl_half_max.py
vendored
Normal file
13
tinygrad_repo/test/external/external_cl_half_max.py
vendored
Normal file
@@ -0,0 +1,13 @@
|
||||
from tinygrad.runtime.ops_cl import CLDevice, CLProgram, compile_cl
|
||||
|
||||
if __name__ == "__main__":
|
||||
dev = CLDevice()
|
||||
lib = compile_cl("""
|
||||
#pragma OPENCL EXTENSION cl_khr_fp16 : enable
|
||||
__kernel void test(__global half *out, __global half *a, __global half *b) {
|
||||
int gid = get_global_id(0);
|
||||
out[gid] = max(a[gid], b[gid]);
|
||||
}
|
||||
""")
|
||||
prg = CLProgram(dev, "test", lib)
|
||||
|
||||
Reference in New Issue
Block a user